summaryrefslogtreecommitdiffstats
path: root/etherpad
diff options
context:
space:
mode:
Diffstat (limited to 'etherpad')
-rw-r--r--etherpad/src/etherpad/billing/team_billing.js6
-rw-r--r--etherpad/src/etherpad/control/aboutcontrol.js4
-rw-r--r--etherpad/src/etherpad/control/global_pro_account_control.js2
-rw-r--r--etherpad/src/etherpad/control/historycontrol.js2
-rw-r--r--etherpad/src/etherpad/control/pad/pad_control.js6
-rw-r--r--etherpad/src/etherpad/control/pro/admin/pro_admin_control.js2
-rw-r--r--etherpad/src/etherpad/control/pro/admin/team_billing_control.js8
-rw-r--r--etherpad/src/etherpad/control/pro/pro_main_control.js1
-rw-r--r--etherpad/src/etherpad/control/pro_beta_control.js2
-rw-r--r--etherpad/src/etherpad/control/pro_help_control.js60
-rw-r--r--etherpad/src/etherpad/control/pro_signup_control.js2
-rw-r--r--etherpad/src/etherpad/control/statscontrol.js6
-rw-r--r--etherpad/src/etherpad/control/store/eepnet_checkout_control.js8
-rw-r--r--etherpad/src/etherpad/helpers.js4
-rw-r--r--etherpad/src/etherpad/licensing.js2
-rw-r--r--etherpad/src/etherpad/metrics/metrics.js4
-rw-r--r--etherpad/src/etherpad/pad/exporthtml.js5
-rw-r--r--etherpad/src/etherpad/pad/pad_migrations.js2
-rw-r--r--etherpad/src/etherpad/pad/padutils.js2
-rw-r--r--etherpad/src/etherpad/pro/pro_accounts.js2
-rw-r--r--etherpad/src/etherpad/pro/pro_utils.js8
-rw-r--r--etherpad/src/etherpad/quotas.js4
-rw-r--r--etherpad/src/etherpad/sessions.js1
-rw-r--r--etherpad/src/etherpad/store/checkout.js2
-rw-r--r--etherpad/src/etherpad/store/eepnet_checkout.js4
-rw-r--r--etherpad/src/etherpad/store/eepnet_trial.js6
-rw-r--r--etherpad/src/main.js8
-rw-r--r--etherpad/src/static/crossdomain.xml10
-rw-r--r--etherpad/src/static/css/broadcast.css25
-rw-r--r--etherpad/src/static/css/pad2_ejs.css34
-rw-r--r--etherpad/src/static/css/pro-help.css19
-rw-r--r--etherpad/src/static/favicon.icobin1150 -> 1354 bytes
-rw-r--r--etherpad/src/static/img/jun09/pad/padtop5.pngbin0 -> 6604 bytes
-rw-r--r--etherpad/src/static/img/jun09/pad/padtop5.xcfbin0 -> 44819 bytes
-rw-r--r--etherpad/src/static/img/jun09/pad/protop.gifbin3374 -> 0 bytes
-rw-r--r--etherpad/src/static/img/pro/header/pro-header-logo.pngbin2213 -> 5527 bytes
-rw-r--r--etherpad/src/static/js/broadcast_slider.js2
-rw-r--r--etherpad/src/static/js/etherpad.js4
-rw-r--r--etherpad/src/static/js/pad_modals.js4
-rw-r--r--etherpad/src/static/js/pro/guest-knock-client.js2
-rw-r--r--etherpad/src/themes/default/templates/500_body.ejs2
-rw-r--r--etherpad/src/themes/default/templates/email/padinvite.ejs2
-rw-r--r--etherpad/src/themes/default/templates/framed/framedheader-pro.ejs5
-rw-r--r--etherpad/src/themes/default/templates/main/home.ejs32
-rw-r--r--etherpad/src/themes/default/templates/main/pro_signup_body.ejs5
-rw-r--r--etherpad/src/themes/default/templates/pad/create_body.ejs4
-rw-r--r--etherpad/src/themes/default/templates/pad/padview_body.ejs2
-rw-r--r--etherpad/src/themes/default/templates/pro-help/main.ejs35
-rw-r--r--etherpad/src/themes/default/templates/pro-help/pro-help-template.ejs24
-rw-r--r--etherpad/src/themes/default/templates/pro/account/account-welcome-email.ejs2
-rw-r--r--etherpad/src/themes/default/templates/pro/admin/admin-template.ejs8
-rw-r--r--etherpad/src/themes/default/templates/pro/pro_home.ejs11
52 files changed, 135 insertions, 260 deletions
diff --git a/etherpad/src/etherpad/billing/team_billing.js b/etherpad/src/etherpad/billing/team_billing.js
index 54fd62a..ae8ae8a 100644
--- a/etherpad/src/etherpad/billing/team_billing.js
+++ b/etherpad/src/etherpad/billing/team_billing.js
@@ -401,7 +401,7 @@ function sendReceiptEmail(subscription, invoice) {
globals: globals
});
var address = paymentInfo.email;
- checkout.salesEmail(address, "sales@etherpad.com", "EtherPad: Receipt for "+paymentInfo.fullname,
+ checkout.salesEmail(address, "sales@pad.spline.inf.fu-berlin.de", "EtherPad: Receipt for "+paymentInfo.fullname,
{}, emailText);
}
@@ -414,9 +414,9 @@ function sendFailureEmail(subscription, invoice, failureMessage) {
billingError: failureMessage,
balance: "US $"+checkout.dollars(billing.centsToDollars(invoice.amt)),
suspensionDate: checkout.formatDate(new Date(subscription.paidThrough.getTime()+GRACE_PERIOD_DAYS*86400*1000)),
- billingAdminLink: "https://"+subDomain+".etherpad.com/ep/admin/billing/"
+ billingAdminLink: "https://"+subDomain+".pad.spline.inf.fu-berlin.de/ep/admin/billing/"
});
var address = paymentInfo.email;
- checkout.salesEmail(address, "sales@etherpad.com", "EtherPad: Payment Failure for "+paymentInfo.fullname,
+ checkout.salesEmail(address, "sales@pad.spline.inf.fu-berlin.de", "EtherPad: Payment Failure for "+paymentInfo.fullname,
{}, emailText);
} \ No newline at end of file
diff --git a/etherpad/src/etherpad/control/aboutcontrol.js b/etherpad/src/etherpad/control/aboutcontrol.js
index 12265cf..9d77142 100644
--- a/etherpad/src/etherpad/control/aboutcontrol.js
+++ b/etherpad/src/etherpad/control/aboutcontrol.js
@@ -198,11 +198,11 @@ function render_eepnet_pricing_contact_post() {
"This record has automatically been added to SalesForce. See the salesforce lead page for more details.",
"", "Session Referer: "+ref, ""
].join("\n");
- var toAddr = 'sales@etherpad.com';
+ var toAddr = 'sales@pad.spline.inf.fu-berlin.de';
if (isTestEmail(data.email)) {
toAddr = 'blackhole@appjet.com';
}
- sendEmail(toAddr, 'sales@etherpad.com', subject, {}, body);
+ sendEmail(toAddr, 'sales@pad.spline.inf.fu-berlin.de', subject, {}, body);
// all done!
response.write("OK");
diff --git a/etherpad/src/etherpad/control/global_pro_account_control.js b/etherpad/src/etherpad/control/global_pro_account_control.js
index abc2994..65d2124 100644
--- a/etherpad/src/etherpad/control/global_pro_account_control.js
+++ b/etherpad/src/etherpad/control/global_pro_account_control.js
@@ -125,7 +125,7 @@ function render_recover_post() {
response.redirect(_recoverLink(accountList[0], domainList[0]));
}
if (accountList.length > 1) {
- var fromAddr = '"EtherPad Support" <support@etherpad.com>';
+ var fromAddr = '"EtherPad" <noreply@pad.spline.inf.fu-berlin.de>';
var subj = "EtherPad: account information";
var body = renderTemplateAsString(
'pro/account/global-multi-domain-recover-email.ejs', {
diff --git a/etherpad/src/etherpad/control/historycontrol.js b/etherpad/src/etherpad/control/historycontrol.js
index 56fcb8e..a78cfad 100644
--- a/etherpad/src/etherpad/control/historycontrol.js
+++ b/etherpad/src/etherpad/control/historycontrol.js
@@ -86,7 +86,7 @@ function _do_stat(padId) {
function _censorText(text) {
// may not change length of text
- return text.replace(/(http:\/\/etherpad.com\/)(\w+)/g, function(url, u1, u2) {
+ return text.replace(/(http:\/\/pad.spline.inf.fu-berlin.de\/)(\w+)/g, function(url, u1, u2) {
return u1 + u2.replace(/\w/g, '-');
});
}
diff --git a/etherpad/src/etherpad/control/pad/pad_control.js b/etherpad/src/etherpad/control/pad/pad_control.js
index 2a6a1be..32ff8a3 100644
--- a/etherpad/src/etherpad/control/pad/pad_control.js
+++ b/etherpad/src/etherpad/control/pad/pad_control.js
@@ -611,8 +611,8 @@ function render_feedback_post() {
feedback: request.params.feedback});
sendEmail(
- 'feedback@etherpad.com',
- 'feedback@etherpad.com',
+ 'feedback@pad.spline.inf.fu-berlin.de',
+ 'feedback@pad.spline.inf.fu-berlin.de',
subject,
{},
feedback
@@ -635,7 +635,7 @@ function render_emailinvite_post() {
{toEmails: toEmails, padId: padId, username: username,
subject: subject, message: message});
- var fromAddr = '"EtherPad" <noreply@etherpad.com>';
+ var fromAddr = '"EtherPad" <noreply@pad.spline.inf.fu-berlin.de>';
// client enforces non-empty subject and message
var subj = '[EtherPad] '+subject;
var body = renderTemplateAsString('email/padinvite.ejs',
diff --git a/etherpad/src/etherpad/control/pro/admin/pro_admin_control.js b/etherpad/src/etherpad/control/pro/admin/pro_admin_control.js
index 1364176..51d6ba3 100644
--- a/etherpad/src/etherpad/control/pro/admin/pro_admin_control.js
+++ b/etherpad/src/etherpad/control/pro/admin/pro_admin_control.js
@@ -264,7 +264,7 @@ function render_recover_padtext_get() {
if (showPadHelp) {
d.push(P({style: "font-size: 1em; color: #555;"},
'The pad ID is the same as the URL to the pad, without the leading "/".',
- ' For example, if the pad lives at http://etherpad.com/foobar,',
+ ' For example, if the pad lives at http://pad.spline.inf.fu-berlin.de/foobar,',
' then the pad ID is "foobar" (without the quotes).'))
}
diff --git a/etherpad/src/etherpad/control/pro/admin/team_billing_control.js b/etherpad/src/etherpad/control/pro/admin/team_billing_control.js
index 9c5b4d0..5be6a0e 100644
--- a/etherpad/src/etherpad/control/pro/admin/team_billing_control.js
+++ b/etherpad/src/etherpad/control/pro/admin/team_billing_control.js
@@ -250,7 +250,7 @@ function _attemptAuthorization(success_f) {
_validationError('', "A temporary error has prevented processing of your payment. Please try again later.");
} else {
billing.log({'type': 'FATAL', value: "Unknown error: "+result.status+" - debug: "+result.debug});
- sendEmail('support@etherpad.com', 'urgent@etherpad.com', 'UNKNOWN ERROR WARNING!', {},
+ sendEmail('support@pad.spline.inf.fu-berlin.de', 'urgent@pad.spline.inf.fu-berlin.de', 'UNKNOWN ERROR WARNING!', {},
"Hey,\n\nThis is a billing system error. Some unknown error occurred. "+
"This shouldn't ever happen. Probably good to let J.D. know. <grin>\n\n"+
fastJSON.stringify(cart));
@@ -284,7 +284,7 @@ function _processNewSubscription() {
});
if (globals.isProduction()) {
- sendEmail('sales@etherpad.com', 'sales@etherpad.com', "EtherPad: New paid pro account for "+fullName, {},
+ sendEmail('sales@pad.spline.inf.fu-berlin.de', 'sales@pad.spline.inf.fu-berlin.de', "EtherPad: New paid pro account for "+fullName, {},
"This is an automatic notification.\n\n"+fullName+" ("+email+") successfully set up "+
"a billing profile for domain: "+domainName+".");
}
@@ -363,10 +363,10 @@ function _processInvoicePurchase() {
"\nEmail: ",
pro_accounts.getSessionProAccount().email
].join("\n");
- var recipient = (globals.isProduction() ? 'sales@etherpad.com' : 'jd@appjet.com');
+ var recipient = (globals.isProduction() ? 'sales@pad.spline.inf.fu-berlin.de' : 'jd@appjet.com');
sendEmail(
recipient,
- 'sales@etherpad.com',
+ 'sales@pad.spline.inf.fu-berlin.de',
'Invoice payment request - '+pro_utils.getProRequestSubdomain(),
{},
"Hi there,\n\nA pro user tried to pay by invoice. Their information follows."+
diff --git a/etherpad/src/etherpad/control/pro/pro_main_control.js b/etherpad/src/etherpad/control/pro/pro_main_control.js
index f151091..b4e3bc4 100644
--- a/etherpad/src/etherpad/control/pro/pro_main_control.js
+++ b/etherpad/src/etherpad/control/pro/pro_main_control.js
@@ -70,7 +70,6 @@ function render_main() {
renderFramed('pro/pro_home.ejs', {
isEvaluation: licensing.isEvaluation(),
- // evalExpDate: licensing.getLicense().expiresDate,
account: getSessionProAccount(),
isPNE: pne_utils.isPNE(),
pneVersion: pne_utils.getVersionString(),
diff --git a/etherpad/src/etherpad/control/pro_beta_control.js b/etherpad/src/etherpad/control/pro_beta_control.js
index 518e710..ec99b43 100644
--- a/etherpad/src/etherpad/control/pro_beta_control.js
+++ b/etherpad/src/etherpad/control/pro_beta_control.js
@@ -121,7 +121,7 @@ function sendInvite(recordId) {
signupCode: code,
activationUrl: "http://"+httpHost(request.host)+"/ep/pro-signup/?sc="+code
});
- sendEmail(record.email, "EtherPad <support@etherpad.com>",
+ sendEmail(record.email, "EtherPad <support@pad.spline.inf.fu-berlin.de>",
"Your EtherPad Professional Beta Account", {}, body);
});
diff --git a/etherpad/src/etherpad/control/pro_help_control.js b/etherpad/src/etherpad/control/pro_help_control.js
deleted file mode 100644
index 675e976..0000000
--- a/etherpad/src/etherpad/control/pro_help_control.js
+++ /dev/null
@@ -1,60 +0,0 @@
-/**
- * Copyright 2009 Google Inc.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS-IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-import("etherpad.utils.*");
-import("etherpad.globals.*");
-import("etherpad.billing.team_billing");
-
-var _helpTopics = [
-/* ['essentials', "EtherPad Essentials"], */
- ['billing', "Account Quotas and Billing"],
-/* ['guests', "Collaborating with Teammates and Guests"] */
-];
-
-function onRequest() {
- var pageId = request.path.split('/')[3];
- if (!pageId) {
- _renderPage('main');
- return true;
- }
- for (var i = 0; i < _helpTopics.length; i++) {
- var t = _helpTopics[i];
- if (t[0] == pageId) {
- _renderPage(pageId);
- return true;
- }
- }
-
- response.redirect('/ep/pro-help/');
-}
-
-function _renderPage(pageId) {
- function renderContent() {
- return renderTemplateAsString('pro-help/'+pageId+'.ejs', {
- helpTopics: _helpTopics,
- numFreeAccounts: PRO_FREE_ACCOUNTS,
- pricePerAccount: team_billing.COST_PER_USER
- });
- }
-
- renderFramed('pro-help/pro-help-template.ejs', {
- renderContent: renderContent
- });
-}
-
-
-
-
diff --git a/etherpad/src/etherpad/control/pro_signup_control.js b/etherpad/src/etherpad/control/pro_signup_control.js
index 9729d75..6bf7cc3 100644
--- a/etherpad/src/etherpad/control/pro_signup_control.js
+++ b/etherpad/src/etherpad/control/pro_signup_control.js
@@ -134,6 +134,8 @@ function render_main_post() {
_err(pro_accounts.validateFullName(fullName));
_err(pro_accounts.validateEmail(email));
+
+ if (!(email.match(/[Ff][Uu]-[Bb][Ee][Rr][Ll][Ii][Nn].[Dd][Ee]$/))) { _err("Please use your *.fu-berlin.de email address."); }
// _err(pro_accounts.validatePassword(password));
//---- database validation ----
diff --git a/etherpad/src/etherpad/control/statscontrol.js b/etherpad/src/etherpad/control/statscontrol.js
index 435b7ac..3659107 100644
--- a/etherpad/src/etherpad/control/statscontrol.js
+++ b/etherpad/src/etherpad/control/statscontrol.js
@@ -101,7 +101,7 @@ var statDisplays = {
// free pad usage
{ name: "free pad usage, 1 day",
- description: "Free etherpad.com users, total over a %t period",
+ description: "Free pad.spline.inf.fu-berlin.de users, total over a %t period",
type: "compare",
stats: [ {stat: "active_user_ids",
description: "All users",
@@ -113,7 +113,7 @@ var statDisplays = {
description: "Users returning after 30 days",
color: "FF0000"} ] },
{ name: "free pad usage, 7 day",
- description: "Free etherpad.com users over the last 7 days",
+ description: "Free pad.spline.inf.fu-berlin.de users over the last 7 days",
type: "compare",
options: { hideLive: true, latestUseHistorical: true},
stats: [ {stat: "active_user_ids_7days",
@@ -126,7 +126,7 @@ var statDisplays = {
description: "Users returning after 30 days",
color: "FF0000"} ] },
{ name: "free pad usage, 30 day",
- description: "Free etherpad.com users over the last 30 days",
+ description: "Free pad.spline.inf.fu-berlin.de users over the last 30 days",
type: "compare",
options: { hideLive: true, latestUseHistorical: true},
stats: [ {stat: "active_user_ids_30days",
diff --git a/etherpad/src/etherpad/control/store/eepnet_checkout_control.js b/etherpad/src/etherpad/control/store/eepnet_checkout_control.js
index eb18381..ddd4973 100644
--- a/etherpad/src/etherpad/control/store/eepnet_checkout_control.js
+++ b/etherpad/src/etherpad/control/store/eepnet_checkout_control.js
@@ -671,7 +671,7 @@ function _performCreditCardPurchase() {
billing.log({'type': 'FATAL', value: "Direct purchase failed on paypal.", cart: cart, paypal: paypalResult});
if (result.errorField.permanentErrors[0] == 'invoiceId') {
// repeat invoice id. damnit, this is bad.
- sendEmail('support@etherpad.com', 'urgent@etherpad.com', 'DUPLICATE INVOICE WARNING!', {},
+ sendEmail('support@pad.spline.inf.fu-berlin.de', 'urgent@pad.spline.inf.fu-berlin.de', 'DUPLICATE INVOICE WARNING!', {},
"Hey,\n\nThis is a billing system error. The EEPNET checkout tried to make a "+
"purchase with PayPal and got a duplicate invoice error on invoice ID "+cart.invoiceId+
".\n\nUnless you're expecting this (or recently ran a selenium test, or have reason to "+
@@ -679,8 +679,8 @@ function _performCreditCardPurchase() {
"and get back to the user ASAP!\n\n"+fastJSON.stringify(cart));
_validationError('', "Your payment was processed, but we cannot proceed. "+
"You will hear from us shortly via email. (If you don't hear from us "+
- "within 24 hours, please email <a href='mailto:sales@etherpad.com'>"+
- "sales@etherpad.com</a>.)");
+ "within 24 hours, please email <a href='mailto:sales@pad.spline.inf.fu-berlin.de'>"+
+ "sales@pad.spline.inf.fu-berlin.de</a>.)");
}
checkout.validateErrorFields(function(x, y) { _validationError(x, y, 'billing-info') }, "There seems to be an error in your billing information."+
" Please verify and correct your ",
@@ -690,7 +690,7 @@ function _performCreditCardPurchase() {
_validationError('', "A temporary error has prevented processing of your payment. Please try again later.");
} else {
billing.log({'type': 'FATAL', value: "Unknown error: "+result.status+" - debug: "+result.debug});
- sendEmail('support@etherpad.com', 'urgent@etherpad.com', 'UNKNOWN ERROR WARNING!', {},
+ sendEmail('support@pad.spline.inf.fu-berlin.de', 'urgent@pad.spline.inf.fu-berlin.de', 'UNKNOWN ERROR WARNING!', {},
"Hey,\n\nThis is a billing system error. Some unknown error occurred. "+
"This shouldn't ever happen. Probably good to let J.D. know. <grin>\n\n"+
fastJSON.stringify(cart));
diff --git a/etherpad/src/etherpad/helpers.js b/etherpad/src/etherpad/helpers.js
index 54bee2d..3996a3b 100644
--- a/etherpad/src/etherpad/helpers.js
+++ b/etherpad/src/etherpad/helpers.js
@@ -198,8 +198,8 @@ function cssIncludes() {
}
function oemail(username) {
- return '&lt;<a class="obfuscemail" href="mailto:'+username+'@e***rp*d.com">'+
- username+'@e***rp*d.com</a>&gt;';
+ return '&lt;<a class="obfuscemail" href="mailto:'+username+'@p*d.sp***e.inf.fu-berlin.de">'+
+ username+'@p*d.sp***e.inf.fu-berlin.de</a>&gt;';
}
function googleAnalytics() {
diff --git a/etherpad/src/etherpad/licensing.js b/etherpad/src/etherpad/licensing.js
index d57fa4c..2337456 100644
--- a/etherpad/src/etherpad/licensing.js
+++ b/etherpad/src/etherpad/licensing.js
@@ -17,7 +17,7 @@
/*
* This file used to control access restrictions for various sites like
- * etherpad.com or on-prem installations of etherpad, or evaluation
+ * pad.spline.inf.fu-berlin.de or on-prem installations of etherpad, or evaluation
* editions. For the open-source effort, I have gutted out the
* restrictions. --aiba
*/
diff --git a/etherpad/src/etherpad/metrics/metrics.js b/etherpad/src/etherpad/metrics/metrics.js
index 1bc8666..435a5be 100644
--- a/etherpad/src/etherpad/metrics/metrics.js
+++ b/etherpad/src/etherpad/metrics/metrics.js
@@ -329,8 +329,8 @@ function getOrigins(startDate, endDate, useReferer, shouldAggregatePads) {
});
if (useReferer) {
- flowFirsts = flowFirsts.filter(function(x) { return ! startsWith(x, "http://etherpad.com"); });
- sessionKeyFirsts = sessionKeyFirsts.filter(function(x) { return ! startsWith(x, "http://etherpad.com"); });
+ flowFirsts = flowFirsts.filter(function(x) { return ! startsWith(x, "http://pad.spline.inf.fu-berlin.de"); });
+ sessionKeyFirsts = sessionKeyFirsts.filter(function(x) { return ! startsWith(x, "http://pad.spline.inf.fu-berlin.de"); });
}
return {
diff --git a/etherpad/src/etherpad/pad/exporthtml.js b/etherpad/src/etherpad/pad/exporthtml.js
index 48ea1a4..2512603 100644
--- a/etherpad/src/etherpad/pad/exporthtml.js
+++ b/etherpad/src/etherpad/pad/exporthtml.js
@@ -47,8 +47,8 @@ function getPadHTML(pad, revNum) {
var apool = pad.pool();
- var tags = ['b','i','u','s'];
- var props = ['bold','italic','underline','strikethrough'];
+ var tags = ['b','i','u','s','h1','h2','h3','h4','h5','h6'];
+ var props = ['bold','italic','underline','strikethrough','h1','h2','h3','h4','h5','h6'];
var anumMap = {};
props.forEach(function(propName, i) {
var propTrueNum = apool.putAttrib([propName,true], true);
@@ -288,6 +288,7 @@ function getPadHTMLDocument(pad, revNum, noDocType) {
'<meta http-equiv="Content-type" content="text/html; charset=utf-8" />\n'+
'<meta http-equiv="Content-Language" content="en-us" />\n'+
'<title>'+'/'+pad.getId()+'</title>\n'+
+ '<style type="text/css">h1,h2,h3,h4,h5,h6 { display: inline; }</style>\n' +
'</head>\n')+
'<body>';
diff --git a/etherpad/src/etherpad/pad/pad_migrations.js b/etherpad/src/etherpad/pad/pad_migrations.js
index f502bdf..e81cf63 100644
--- a/etherpad/src/etherpad/pad/pad_migrations.js
+++ b/etherpad/src/etherpad/pad/pad_migrations.js
@@ -31,7 +31,7 @@ function onStartup() {
appjet.cache.pad_migrations = {};
}
- // this part can be removed when all pads are migrated on etherpad.com
+ // this part can be removed when all pads are migrated on pad.spline.inf.fu-berlin.de
//if (! pne_utils.isPNE()) {
// System.out.println("Building cache for live migrations...");
// initLiveMigration();
diff --git a/etherpad/src/etherpad/pad/padutils.js b/etherpad/src/etherpad/pad/padutils.js
index dc4c9ab..b53de11 100644
--- a/etherpad/src/etherpad/pad/padutils.js
+++ b/etherpad/src/etherpad/pad/padutils.js
@@ -98,7 +98,7 @@ function getGlobalPadId(localPadId) {
if (pro_utils.isProDomainRequest()) {
return makeGlobalId(domains.getRequestDomainId(), localPadId);
} else {
- // etherpad.com pads
+ // pad.spline.inf.fu-berlin.de pads
return localPadId;
}
}
diff --git a/etherpad/src/etherpad/pro/pro_accounts.js b/etherpad/src/etherpad/pro/pro_accounts.js
index 54ac50c..98df6bb 100644
--- a/etherpad/src/etherpad/pro/pro_accounts.js
+++ b/etherpad/src/etherpad/pro/pro_accounts.js
@@ -564,7 +564,7 @@ function getEtherpadAdminAccount() {
id: 0,
isAdmin: true,
fullName: "ETHERPAD ADMIN",
- email: "support@etherpad.com",
+ email: "support@pad.spline.inf.fu-berlin.de",
domainId: domains.getRequestDomainId(),
isDeleted: false
};
diff --git a/etherpad/src/etherpad/pro/pro_utils.js b/etherpad/src/etherpad/pro/pro_utils.js
index 1198b95..d3098d7 100644
--- a/etherpad/src/etherpad/pro/pro_utils.js
+++ b/etherpad/src/etherpad/pro/pro_utils.js
@@ -45,8 +45,8 @@ function getProRequestSubdomain() {
return d.split('.')[0];
}
-function getRequestSuperdomain() {
- var parts = request.domain.split('.');
+function getRequestSuperdomain() {
+ var parts = request.domain.split('.');
while (parts.length > 0) {
var domain = parts.join('.');
if (domainEnabled(domain)) {
@@ -55,7 +55,7 @@ function getRequestSuperdomain() {
parts.shift();
}
return false;
-}
+}
function isProDomainRequest() {
if(!isProAccountEnabled())
@@ -151,7 +151,7 @@ function getFullSuperdomainHost() {
}
function getEmailFromAddr() {
- var fromDomain = 'etherpad.com';
+ var fromDomain = 'pad.spline.inf.fu-berlin.de';
if (pne_utils.isPNE()) {
fromDomain = getFullProDomain();
}
diff --git a/etherpad/src/etherpad/quotas.js b/etherpad/src/etherpad/quotas.js
index 99ce205..7e939ec 100644
--- a/etherpad/src/etherpad/quotas.js
+++ b/etherpad/src/etherpad/quotas.js
@@ -29,7 +29,7 @@ function getMaxSimultaneousPadEditors(globalPadId) {
return 1e6;
}
} else {
- // etherpad.com public pads
+ // pad.spline.inf.fu-berlin.de public pads
if (globalPadId && stringutils.startsWith(globalPadId, "conf-")) {
return 64;
} else {
@@ -43,7 +43,7 @@ function getMaxSavedRevisionsPerPad() {
if (isProDomainRequest()) {
return 1e3;
} else {
- // free public etherpad.com
+ // free public pad.spline.inf.fu-berlin.de
return 100;
}
}
diff --git a/etherpad/src/etherpad/sessions.js b/etherpad/src/etherpad/sessions.js
index 3c10963..f430ddd 100644
--- a/etherpad/src/etherpad/sessions.js
+++ b/etherpad/src/etherpad/sessions.js
@@ -63,7 +63,6 @@ function _getScopedDomain(subDomain) {
}
return "." + d;
}
-
//--------------------------------------------------------------------------------
// pass in subDomain to get the session data for a particular subdomain --
diff --git a/etherpad/src/etherpad/store/checkout.js b/etherpad/src/etherpad/store/checkout.js
index 7b8e224..2a4d7e7 100644
--- a/etherpad/src/etherpad/store/checkout.js
+++ b/etherpad/src/etherpad/store/checkout.js
@@ -295,6 +295,6 @@ function formatDate(date) {
function salesEmail(to, from, subject, headers, body) {
sendEmail(to, from, subject, headers, body);
if (globals.isProduction()) {
- sendEmail("sales@etherpad.com", from, subject, headers, body);
+ sendEmail("sales@pad.spline.inf.fu-berlin.de", from, subject, headers, body);
}
} \ No newline at end of file
diff --git a/etherpad/src/etherpad/store/eepnet_checkout.js b/etherpad/src/etherpad/store/eepnet_checkout.js
index cdf32a1..62137d3 100644
--- a/etherpad/src/etherpad/store/eepnet_checkout.js
+++ b/etherpad/src/etherpad/store/eepnet_checkout.js
@@ -87,7 +87,7 @@ function licenseEmailText(userName, licenseKey) {
function sendReceiptEmail(cart) {
var receipt = cart.receiptEmail || receiptEmailText(cart);
- salesEmail(cart.email, "sales@etherpad.com",
+ salesEmail(cart.email, "sales@pad.spline.inf.fu-berlin.de",
"EtherPad: Receipt for "+cart.ownerName+" ("+cart.orgName+")",
{}, receipt);
}
@@ -95,7 +95,7 @@ function sendReceiptEmail(cart) {
function sendLicenseEmail(cart) {
var licenseEmail = licenseEmailText(cart.ownerName, cart.licenseKey);
- salesEmail(cart.email, "sales@etherpad.com",
+ salesEmail(cart.email, "sales@pad.spline.inf.fu-berlin.de",
"EtherPad: License Key for "+cart.ownerName+" ("+cart.orgName+")",
{}, licenseEmail);
} \ No newline at end of file
diff --git a/etherpad/src/etherpad/store/eepnet_trial.js b/etherpad/src/etherpad/store/eepnet_trial.js
index 20fccdc..570d351 100644
--- a/etherpad/src/etherpad/store/eepnet_trial.js
+++ b/etherpad/src/etherpad/store/eepnet_trial.js
@@ -52,7 +52,7 @@ function mailLicense(data, licenseKey, expiresDate) {
sendEmail(
toAddr,
- 'sales@etherpad.com',
+ 'sales@pad.spline.inf.fu-berlin.de',
subject,
{},
emailBody
@@ -188,13 +188,13 @@ function _sendSalesNotification(data, ip, ref) {
""
].join("\n");
- var toAddr = 'sales@etherpad.com';
+ var toAddr = 'sales@pad.spline.inf.fu-berlin.de';
if (isTestEmail(data.email)) {
toAddr = 'blackhole@appjet.com';
}
sendEmail(
toAddr,
- 'sales@etherpad.com',
+ 'sales@pad.spline.inf.fu-berlin.de',
subject,
{'Reply-To': data.email},
body
diff --git a/etherpad/src/static/crossdomain.xml b/etherpad/src/static/crossdomain.xml
index 1074b2a..9e76390 100644
--- a/etherpad/src/static/crossdomain.xml
+++ b/etherpad/src/static/crossdomain.xml
@@ -3,8 +3,10 @@
xsi:noNamespaceSchemaLocation="http://www.adobe.com/xml/schemas/PolicyFile.xsd">
<site-control permitted-cross-domain-policies="all"/>
<allow-http-request-headers-from domain="*" headers="*"/>
-<allow-access-from domain="*.tokbox.com" to-ports="*"/>
-<allow-access-from domain="tokbox.com" to-ports="*"/>
-<allow-access-from domain="*.etherpad.com" to-ports="*"/>
-<allow-access-from domain="etherpad.com" to-ports="*"/>
+<allow-access-from domain="*.pad.spline.de" to-ports="*"/>
+<allow-access-from domain="pad.spline.de" to-ports="*"/>
+<allow-access-from domain="*.pad.spline.inf.fu-berlin.de" to-ports="*"/>
+<allow-access-from domain="pad.spline.inf.fu-berlin.de" to-ports="*"/>
+<allow-access-from domain="*.pad.spline.nomad" to-ports="*"/>
+<allow-access-from domain="pad.spline.nomad" to-ports="*"/>
</cross-domain-policy>
diff --git a/etherpad/src/static/css/broadcast.css b/etherpad/src/static/css/broadcast.css
index 9114f8e..afb65b8 100644
--- a/etherpad/src/static/css/broadcast.css
+++ b/etherpad/src/static/css/broadcast.css
@@ -1,6 +1,5 @@
-*,html.body,p { margin: 0; padding: 0; }
-h1, h2, h3, h4, h5, h6 { font-size: 100%; font-weight: normal; font-style: normal;
- text-decoration: none; margin: 0; padding: 0; }
+*,html.body { margin: 0; padding: 0; }
+h1, h2, h3, h4, h5, h6 { display: inline; line-height: 2em; }
.clear { clear: both; }
@@ -15,14 +14,14 @@ body, textarea { font-family: Arial, sans-serif; }
#padpage { margin-left: auto; margin-right: auto; width: 914px; vertical-align: top;}
#topbarleft { float: left; height: 100%; overflow: hidden;
- background: url(/static/img/jun09/pad/padtop4.gif) no-repeat left top; width: 5px; }
+ background: url(/static/img/jun09/pad/padtop4.png) no-repeat left top; width: 5px; }
#topbarright { float: right; height: 100%; overflow: hidden;
- background: url(/static/img/jun09/pad/padtop4.gif) no-repeat right top; width: 5px; }
+ background: url(/static/img/jun09/pad/padtop4.png) no-repeat right top; width: 5px; }
-.propad #topbar { background: #2c2c2c url(/static/img/jun09/pad/protop.gif) repeat-x 0 -25px; }
-.propad #topbarleft { background: url(/static/img/jun09/pad/protop.gif) no-repeat left top; }
-.propad #topbarright { background: url(/static/img/jun09/pad/protop.gif) no-repeat right top; }
+.propad #topbar { background: #2c2c2c url(/static/img/jun09/pad/protop.png) repeat-x 0 -25px; }
+.propad #topbarleft { background: url(/static/img/jun09/pad/protop.png) no-repeat left top; }
+.propad #topbarright { background: url(/static/img/jun09/pad/protop.png) no-repeat right top; }
a#backtoprosite, #accountnav {
display: block; position: absolute; height: 15px; line-height: 15px;
@@ -33,11 +32,11 @@ a#backtoprosite, #accountnav a { color: #cde7ff; text-decoration: underline; }
#topbarcenter { margin-left: 150px; margin-right: 150px; }
-a#topbaretherpad { margin-left: auto; margin-right: auto; display: block; width: 103px;
- position: relative; top: 3px; height: 0; padding-top: 20px;
- background: url(/static/img/jun09/pad/padtop4.gif) no-repeat -397px -3px; overflow: hidden; }
+a#topbaretherpad { margin-left: auto; margin-right: auto; display: block; width: 127px;
+ position: relative; top: 0px; height: 0; padding-top: 25px;
+ background: url(/static/img/jun09/pad/padtop4.png) no-repeat -397px 0px; overflow: hidden; }
-.propad a#topbaretherpad { background: url(/static/img/jun09/pad/protop.gif) no-repeat -397px -3px; }
+.propad a#topbaretherpad { background: url(/static/img/jun09/pad/protop.png) no-repeat -397px 0px; }
#padmain {
margin: 7px;
@@ -384,4 +383,4 @@ div #timeslider div#steppers div#rightstep {
#error a {
color: rgb(50, 132, 213);
text-decoration: none;
-} \ No newline at end of file
+}
diff --git a/etherpad/src/static/css/pad2_ejs.css b/etherpad/src/static/css/pad2_ejs.css
index 0519a9d..71176ee 100644
--- a/etherpad/src/static/css/pad2_ejs.css
+++ b/etherpad/src/static/css/pad2_ejs.css
@@ -1,7 +1,7 @@
-*,html.body,p { margin: 0; padding: 0; }
-h1, h2, h3, h4, h5, h6 { font-size: 100%; font-weight: normal; font-style: normal;
- text-decoration: none; margin: 0; padding: 0; }
+*,html.body { margin: 0; padding: 0; }
+
+h1, h2, h3, h4, h5, h6 { display: inline; line-height: 2em; }
.clear { clear: both; }
@@ -12,21 +12,21 @@ body, textarea { font-family: Arial, sans-serif; }
#padpage { margin-left: auto; margin-right: auto; width: 900px; }
-body.fullwidth #padpage { width: auto; margin-left: 6px; margin-right: 6px; }
-body.squish1width #padpage { width: 800px; }
-body.squish2width #padpage { width: 700px; }
+body.fullwidth #padpage { width: auto; margin-left: 6px; margin-right: 6px; min-width: 800px; }
+body.squish1width #padpage { width: 900px; }
+body.squish2width #padpage { width: 800px; }
#topbar { height: 25px; background: #326cbd url(/static/img/jun09/pad/padtopback2.gif) repeat-x left top;
position: relative; }
#topbarleft { float: left; height: 100%; overflow: hidden;
- background: url(/static/img/jun09/pad/padtop5.gif) no-repeat left top; width: 5px; }
+ background: url(/static/img/jun09/pad/padtop5.png) no-repeat left top; width: 5px; }
#topbarright { float: right; height: 100%; overflow: hidden;
- background: url(/static/img/jun09/pad/padtop5.gif) no-repeat right top; width: 5px; }
+ background: url(/static/img/jun09/pad/padtop5.png) no-repeat right top; width: 5px; }
-.propad #topbar { background: #2c2c2c url(/static/img/jun09/pad/protop.gif) repeat-x 0 -25px; }
-.propad #topbarleft { background: url(/static/img/jun09/pad/protop.gif) no-repeat left top; }
-.propad #topbarright { background: url(/static/img/jun09/pad/protop.gif) no-repeat right top; }
+.propad #topbar { background: #2c2c2c url(/static/img/jun09/pad/protop.png) repeat-x 0 -25px; }
+.propad #topbarleft { background: url(/static/img/jun09/pad/protop.png) no-repeat left top; }
+.propad #topbarright { background: url(/static/img/jun09/pad/protop.png) no-repeat right top; }
a#backtoprosite, #accountnav {
display: block; position: absolute; height: 15px; line-height: 15px;
@@ -35,15 +35,15 @@ a#backtoprosite, #accountnav {
a#backtoprosite, #accountnav a { color: #cde7ff; text-decoration: underline; }
a#backtoprosite { padding-left: 20px; left: 6px;
- background: url(/static/img/jun09/pad/protop.gif) no-repeat -5px -6px; }
+ background: url(/static/img/jun09/pad/protop.png) no-repeat -5px -6px; }
#accountnav { right: 10px; color: #fff; }
#topbarcenter { margin-left: 150px; margin-right: 150px; }
-a#topbaretherpad { margin-left: auto; margin-right: auto; display: block; width: 103px;
- position: relative; top: 3px; height: 0; padding-top: 20px;
- background: url(/static/img/jun09/pad/padtop5.gif) no-repeat -397px -3px; overflow: hidden; }
+a#topbaretherpad { margin-left: auto; margin-right: auto; display: block; width: 127px;
+ position: relative; top: 0px; height: 0; padding-top: 25px;
+ background: url(/static/img/jun09/pad/padtop5.png) no-repeat -397px 0px; overflow: hidden; }
-.propad a#topbaretherpad { background: url(/static/img/jun09/pad/protop.gif) no-repeat -397px -3px; }
+.propad a#topbaretherpad { background: url(/static/img/jun09/pad/protop.png) no-repeat -397px 0px; }
#specialkeyarea { top: 5px; left: 250px; color: yellow; font-weight: bold;
font-size: 1.5em; position: absolute; }
@@ -489,7 +489,7 @@ table#otheruserstable { display: none; }
down on the page in IE. Strange but it works! */
#docbar { z-index: 52; }
-#impexp-wrapper { width: 650px; right: 10px; }
+#impexp-wrapper { width: 500px; right: 10px; }
#impexp-panel { height: 160px; }
.docbarimpexp-closing #impexp-wrapper { z-index: 50; }
diff --git a/etherpad/src/static/css/pro-help.css b/etherpad/src/static/css/pro-help.css
deleted file mode 100644
index 9237b62..0000000
--- a/etherpad/src/static/css/pro-help.css
+++ /dev/null
@@ -1,19 +0,0 @@
-
-h1 {
- font-size: 1.33em;
- color: #555;
- border-bottom: 1px solid #888;
-}
-
-h2 {
- font-size: 1.1em;
- color: #333;
- border-bottom: 1px solid #888;
-}
-
-div.pro-help {
- font-size: 88%;
- width: 66%;
-}
-
-
diff --git a/etherpad/src/static/favicon.ico b/etherpad/src/static/favicon.ico
index a19a1cb..a833c3a 100644
--- a/etherpad/src/static/favicon.ico
+++ b/etherpad/src/static/favicon.ico
Binary files differ
diff --git a/etherpad/src/static/img/jun09/pad/padtop5.png b/etherpad/src/static/img/jun09/pad/padtop5.png
new file mode 100644
index 0000000..22a0db7
--- /dev/null
+++ b/etherpad/src/static/img/jun09/pad/padtop5.png
Binary files differ
diff --git a/etherpad/src/static/img/jun09/pad/padtop5.xcf b/etherpad/src/static/img/jun09/pad/padtop5.xcf
new file mode 100644
index 0000000..c0bf7e4
--- /dev/null
+++ b/etherpad/src/static/img/jun09/pad/padtop5.xcf
Binary files differ
diff --git a/etherpad/src/static/img/jun09/pad/protop.gif b/etherpad/src/static/img/jun09/pad/protop.gif
deleted file mode 100644
index 9171646..0000000
--- a/etherpad/src/static/img/jun09/pad/protop.gif
+++ /dev/null
Binary files differ
diff --git a/etherpad/src/static/img/pro/header/pro-header-logo.png b/etherpad/src/static/img/pro/header/pro-header-logo.png
index c1a003c..b36daa8 100644
--- a/etherpad/src/static/img/pro/header/pro-header-logo.png
+++ b/etherpad/src/static/img/pro/header/pro-header-logo.png
Binary files differ
diff --git a/etherpad/src/static/js/broadcast_slider.js b/etherpad/src/static/js/broadcast_slider.js
index 8977e3d..371663e 100644
--- a/etherpad/src/static/js/broadcast_slider.js
+++ b/etherpad/src/static/js/broadcast_slider.js
@@ -398,4 +398,4 @@ var global = this;
BroadcastSlider.onSlider(function(loc) {
$("#viewlatest").html(loc==BroadcastSlider.getSliderLength()?"Viewing latest content":"View latest content");
-}) \ No newline at end of file
+})
diff --git a/etherpad/src/static/js/etherpad.js b/etherpad/src/static/js/etherpad.js
index feca517..4e51dbf 100644
--- a/etherpad/src/static/js/etherpad.js
+++ b/etherpad/src/static/js/etherpad.js
@@ -47,8 +47,8 @@ etherpad.validEmail = function(x) {
etherpad.deobfuscateEmails = function() {
$("a.obfuscemail").each(function() {
- $(this).html($(this).html().replace('e***rp*d','etherpad'));
- this.href = this.href.replace('e***rp*d','etherpad');
+ $(this).html($(this).html().replace('p*d.sp***e','pad.spline'));
+ this.href = this.href.replace('p*d.sp***e','pad.spline');
});
};
diff --git a/etherpad/src/static/js/pad_modals.js b/etherpad/src/static/js/pad_modals.js
index 35a1155..c9f48b5 100644
--- a/etherpad/src/static/js/pad_modals.js
+++ b/etherpad/src/static/js/pad_modals.js
@@ -131,7 +131,7 @@ var padmodals = (function() {
});
$("#feedbackemails a").each(function() {
var node = $(this);
- node.attr('href', "mailto:"+node.attr('href')+"@etherpad.com");
+ node.attr('href', "mailto:"+node.attr('href')+"@pad.spline.inf.fu-berlin.de");
});
},
initShareBox: function() {
@@ -280,7 +280,7 @@ var padmodals = (function() {
}
function error(e) {
setSendingFeedback(false);
- $("#feedbackbox-response").html("Could not send feedback. Please email us at feedback"+"@"+"etherpad.com instead.").get(0).className = 'badresponse';
+ $("#feedbackbox-response").html("Could not send feedback. Please email us at feedback"+"@"+"pad.spline.inf.fu-berlin.de instead.").get(0).className = 'badresponse';
$("#feedbackbox-response").show();
}
},*/
diff --git a/etherpad/src/static/js/pro/guest-knock-client.js b/etherpad/src/static/js/pro/guest-knock-client.js
index 16424d9..bace225 100644
--- a/etherpad/src/static/js/pro/guest-knock-client.js
+++ b/etherpad/src/static/js/pro/guest-knock-client.js
@@ -44,7 +44,7 @@ function knockReply(responseText) {
}
function knockError() {
- alert("There was an error requesting access to the pad. Kindly report this by sending email to bugs@etherpad.com.");
+ alert("There was an error requesting access to the pad. Kindly report this by sending email to bugs@pad.spline.inf.fu-berlin.de.");
}
$(document).ready(function() {
diff --git a/etherpad/src/themes/default/templates/500_body.ejs b/etherpad/src/themes/default/templates/500_body.ejs
index 291e0fd..34549ed 100644
--- a/etherpad/src/themes/default/templates/500_body.ejs
+++ b/etherpad/src/themes/default/templates/500_body.ejs
@@ -19,7 +19,7 @@ limitations under the License. */ %><% helpers.setHtmlTitle("EtherPad Internal S
<div id="errorpage" class="fpcontent">
<div class="error500">
<p>Oops! A server error occured. It's been logged.</p>
- <p>Please email &lt;support@etherpad.com&gt; if this persists.</p>
+ <p>Please email &lt;support@pad.spline.inf.fu-berlin.de&gt; if this persists.</p>
</div>
</div>
<% } %>
diff --git a/etherpad/src/themes/default/templates/email/padinvite.ejs b/etherpad/src/themes/default/templates/email/padinvite.ejs
index c6467b8..0f729e3 100644
--- a/etherpad/src/themes/default/templates/email/padinvite.ejs
+++ b/etherpad/src/themes/default/templates/email/padinvite.ejs
@@ -15,4 +15,4 @@ limitations under the License. */ %><%= body %>
--
Sent by <%= request.host %> at the request of an EtherPad user.
Do not reply to this email.
-Report abuse to: support@etherpad.com
+Report abuse to: support@pad.spline.inf.fu-berlin.de
diff --git a/etherpad/src/themes/default/templates/framed/framedheader-pro.ejs b/etherpad/src/themes/default/templates/framed/framedheader-pro.ejs
index 73b0e99..afb8a67 100644
--- a/etherpad/src/themes/default/templates/framed/framedheader-pro.ejs
+++ b/etherpad/src/themes/default/templates/framed/framedheader-pro.ejs
@@ -47,7 +47,6 @@ limitations under the License. */ %><% helpers.addBodyClass("pro-withtopbar"); %
['/', 'Home', 'home'],
['/ep/padlist/', 'Pads', 'padlist'],
['/ep/account/', 'My Account', 'account'],
- ['/ep/pro-help/', 'Help', 'help']
];
if (account && account.isAdmin) {
links.push(['/ep/admin/', 'Admin', 'admin']);
@@ -66,8 +65,8 @@ limitations under the License. */ %><% helpers.addBodyClass("pro-withtopbar"); %
<div id="pro-topnav">
<div id="pro-topnav-inner">
- <%= renderProTopNav() %>
- <%= helpers.clearFloats() %>
+ <%= renderProTopNav() %>
+ <%= helpers.clearFloats() %>
</div>
</div>
diff --git a/etherpad/src/themes/default/templates/main/home.ejs b/etherpad/src/themes/default/templates/main/home.ejs
index aa5d934..7041bee 100644
--- a/etherpad/src/themes/default/templates/main/home.ejs
+++ b/etherpad/src/themes/default/templates/main/home.ejs
@@ -12,16 +12,16 @@ Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS-IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
-limitations under the License. */ %><% helpers.setHtmlTitle("EtherPad: Open-Sourced!"); %>
+limitations under the License. */ %><% helpers.setHtmlTitle("SplinePad [beta]: Open-Sourced!"); %>
<% helpers.includeCss("home-opensource.css"); %>
<div id="home">
<div id="title">
- EtherPad: Open-Sourced!
+ SplinePad
</div>
- <div>
+ <div id="buttons">
<a id="home-newpad" href="/ep/pad/newpad">
Create new pad
</a>
@@ -31,6 +31,32 @@ limitations under the License. */ %><% helpers.setHtmlTitle("EtherPad: Open-Sour
</a>
<% } %>
</div>
+
+ <div id="tos">
+ <h1>
+ <b>Terms of service and Privacy notice</b>
+ </h1>
+
+ <p>
+ <b>Privacy:</b> We guarantee that we will not intentionally hand
+ over your data to any third party.
+ </p>
+
+ <p>
+ <b>Terms:</b> By using splinepad, you certify to agree to the
+ following terms of service: We are not responsible, and cannot
+ be held liable for any loss or damages that may be caused by the
+ result of our service.
+ </p>
+
+ <p>
+ <b>In short:</b> We love the "Datenschutzgesetz" and if
+ something is wrong, we didn't do it.
+ </p>
+
+ Have fun with splinepad.
+ </div>
+
</div>
diff --git a/etherpad/src/themes/default/templates/main/pro_signup_body.ejs b/etherpad/src/themes/default/templates/main/pro_signup_body.ejs
index e984878..ff35dfc 100644
--- a/etherpad/src/themes/default/templates/main/pro_signup_body.ejs
+++ b/etherpad/src/themes/default/templates/main/pro_signup_body.ejs
@@ -51,8 +51,9 @@ limitations under the License. */ %><% helpers.includeCss('pro-signup.css') %>
<%= inf("email", "Email") %>
</div>
<div class="inputhelp">
- Instructions for choosing a password and signing in will
- be emailed here.
+ <p>Instructions for choosing a password and signing in will
+ be emailed here.</p>
+ <p>Please use your <strong>*.fu-berlin.de</strong> address.</p>
</div>
<%= helpers.clearFloats() %>
</div>
diff --git a/etherpad/src/themes/default/templates/pad/create_body.ejs b/etherpad/src/themes/default/templates/pad/create_body.ejs
index 5fec49a..742821f 100644
--- a/etherpad/src/themes/default/templates/pad/create_body.ejs
+++ b/etherpad/src/themes/default/templates/pad/create_body.ejs
@@ -10,7 +10,7 @@ Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS-IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
-limitations under the License. */ %><% helpers.setHtmlTitle("EtherPad: Create a new pad?"); %>
+limitations under the License. */ %><% helpers.setHtmlTitle("SplinePad [beta]: Create a new pad?"); %>
<div id="createpadpage" class="fpcontent">
<form action="<%= request.path %>" method="post">
@@ -18,7 +18,7 @@ limitations under the License. */ %><% helpers.setHtmlTitle("EtherPad: Create a
<p><tt id="padurl">http://<%= request.host %>/<%= toHTML(padId) %></tt></p>
<br/>
- <p>There is no EtherPad document here. Would you like to create one?</p>
+ <p>There is no SplinePad document here. Would you like to create one?</p>
<input type="hidden" name="padId" value="<%= toHTML(padId) %>" />
<input type="submit" id="createPad" value="Create Pad" />
diff --git a/etherpad/src/themes/default/templates/pad/padview_body.ejs b/etherpad/src/themes/default/templates/pad/padview_body.ejs
index 75c38fe..e18ff12 100644
--- a/etherpad/src/themes/default/templates/pad/padview_body.ejs
+++ b/etherpad/src/themes/default/templates/pad/padview_body.ejs
@@ -113,8 +113,6 @@ limitations under the License. */ %><%
<h2>Download as</h2>
<img src="/static/img/may09/html.gif"><a class="tlink" href="/ep/pad/export/<%= padId %>/<%= revisionId %>?format=html" thref="/ep/pad/export/<%= padId %>/rev.%revision%?format=html">HTML</a><br>
<img src="/static/img/may09/txt.gif" ><a class="tlink" href="/ep/pad/export/<%= padId %>/<%= revisionId %>?format=html" thref="/ep/pad/export/<%= padId %>/rev.%revision%?format=txt" >Plain text</a><br>
-<img src="/static/img/may09/doc.gif" ><a class="tlink" href="/ep/pad/export/<%= padId %>/<%= revisionId %>?format=html" thref="/ep/pad/export/<%= padId %>/rev.%revision%?format=doc" >Microsoft Word</a><br>
-<img src="/static/img/may09/pdf.gif" ><a class="tlink" href="/ep/pad/export/<%= padId %>/<%= revisionId %>?format=html" thref="/ep/pad/export/<%= padId %>/rev.%revision%?format=pdf" >PDF</a>
</div>
diff --git a/etherpad/src/themes/default/templates/pro-help/main.ejs b/etherpad/src/themes/default/templates/pro-help/main.ejs
deleted file mode 100644
index 428d7f7..0000000
--- a/etherpad/src/themes/default/templates/pro-help/main.ejs
+++ /dev/null
@@ -1,35 +0,0 @@
-<% /* Copyright 2009 Google Inc.
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
- http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS-IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License. */ %>
-<h1>EtherPad Professional Edition Help</h1>
-
-<p>These pages are evolving. If you have any questions, or find
-parts of EtherPad confusing, please write in to our Helpdesk by
-emailing <%= helpers.oemail("support") %>.</p>
-
-<p>Please report bugs to <%= helpers.oemail("bugs") %>.</p>
-
-<p>Also note that you can also get help from other users in the <a
-href="http://etherpad.com/ep/about/forums">UserVoice Community
-Forums</a>.</p>
-
-<h2>Help Topics:</h2>
-
-<ul>
-<% helpTopics.forEach(function(t) { %>
- <li><%= A({href: "/ep/pro-help/"+t[0]}, t[1]) %></li>
-<% }); %>
-</ul>
-
-
-
diff --git a/etherpad/src/themes/default/templates/pro-help/pro-help-template.ejs b/etherpad/src/themes/default/templates/pro-help/pro-help-template.ejs
deleted file mode 100644
index 9cc8205..0000000
--- a/etherpad/src/themes/default/templates/pro-help/pro-help-template.ejs
+++ /dev/null
@@ -1,24 +0,0 @@
-<% /* Copyright 2009 Google Inc.
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
- http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS-IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License. */ %><% helpers.includeJQuery() %>
-<% helpers.includeJs("etherpad.js") %>
-<% helpers.includeCss("pro-help.css") %>
-
-<div class="fpcontent">
- <div class="pro-help">
- <%= renderContent() %>
- </div>
-</div>
-
-
-
diff --git a/etherpad/src/themes/default/templates/pro/account/account-welcome-email.ejs b/etherpad/src/themes/default/templates/pro/account/account-welcome-email.ejs
index 25af6f8..33e1ac5 100644
--- a/etherpad/src/themes/default/templates/pro/account/account-welcome-email.ejs
+++ b/etherpad/src/themes/default/templates/pro/account/account-welcome-email.ejs
@@ -22,7 +22,7 @@ Thank you for signing up for EtherPad Professional Edition. You can sign in by
<%= signinLink %>
-For help signing in, or general support issues, please email support@etherpad.com.
+For help signing in, or general support issues, please email support@pad.spline.inf.fu-berlin.de.
--
This email was sent to <%= toEmail %> from an EtherPad user.
diff --git a/etherpad/src/themes/default/templates/pro/admin/admin-template.ejs b/etherpad/src/themes/default/templates/pro/admin/admin-template.ejs
index e1a7736..a54964f 100644
--- a/etherpad/src/themes/default/templates/pro/admin/admin-template.ejs
+++ b/etherpad/src/themes/default/templates/pro/admin/admin-template.ejs
@@ -16,11 +16,9 @@ limitations under the License. */ %><% helpers.setHtmlTitle("Etherpad Administra
<div class="fpcontent">
<table id="admin-layout-table">
<tr>
- <% if (validLicense) { %>
- <td width="1%" id="admin-leftnav">
- <%= renderAdminLeftNav() %>
- </td>
- <% } %>
+ <td width="1%" id="admin-leftnav">
+ <%= renderAdminLeftNav() %>
+ </td>
<td width="99%" id="admin-right">
<%= getAdminContent() %>
</td>
diff --git a/etherpad/src/themes/default/templates/pro/pro_home.ejs b/etherpad/src/themes/default/templates/pro/pro_home.ejs
index 8d92139..bcf7443 100644
--- a/etherpad/src/themes/default/templates/pro/pro_home.ejs
+++ b/etherpad/src/themes/default/templates/pro/pro_home.ejs
@@ -67,20 +67,13 @@ limitations under the License. */ %><% helpers.setHtmlTitle(orgName + " - EtherP
<div class="news-item">
<p>Welcome to your EtherPad Beta Account! Please report bugs by
- sending email to <%= helpers.oemail("bugs") %>. You can also give us
- feedback and feature suggestions via <a target="_blank"
- href="http://uservoice.etherpad.com/">UserVoice</a>.</p>
-
- <p>If you have any questions, just email <%=
- helpers.oemail("support") %> and
- we will respond to your inquiries.</p>
+ sending email to <%= helpers.oemail("bugs") %>.
<p>We hope you enjoy EtherPad!</p>
<p>Sincerely,</p>
- <p>Aaron Iba<br/>
- CEO, AppJet Inc.
+ <p>Spline</p>
</p>
</div>
diff --git a/etherpad/src/main.js b/etherpad/src/main.js
index 738df51..53671cf 100644
--- a/etherpad/src/main.js
+++ b/etherpad/src/main.js
@@ -48,7 +48,6 @@ import("etherpad.control.pro.admin.license_manager_control");
import("etherpad.control.pro_beta_control");
import("etherpad.control.pro.pro_main_control");
import("etherpad.control.pro_signup_control");
-import("etherpad.control.pro_help_control");
import("etherpad.control.scriptcontrol");
import("etherpad.control.static_control");
import("etherpad.control.store.storecontrol");
@@ -276,7 +275,7 @@ function checkHost() {
}
// redirect to main site
- var newurl = "http://etherpad.com"+request.path;
+ var newurl = "http://pad.spline.inf.fu-berlin.de/"+request.path;
if (request.query) { newurl += "?"+request.query; }
response.redirect(newurl);
}
@@ -290,7 +289,7 @@ function checkHTTPS() {
/* Open-source note: this function used to check the protocol and make
* sure that pages that needed to be secure went over HTTPS, and pages
* that didn't go over HTTP. However, when we open-sourced the code,
* we disabled HTTPS because we didn't want to ship the etherpad.com
* private crypto keys. --aiba */
return;
@@ -316,8 +315,6 @@ function checkHTTPS() {
var _requiredHttpsPrefixes = [
'/ep/admin', // pro and main site
'/ep/account', // pro only
- '/ep/store', // main site only
- '/ep/pro-account' // main site only
];
var httpsRequired = false;
@@ -380,7 +377,6 @@ function handlePath() {
[/^\/([^\/]+)$/, pad_control.render_pad],
[DirMatcher('/ep/unit-tests/'), forward(testcontrol)],
[DirMatcher('/ep/pne-manual/'), forward(pne_manual_control)],
- [DirMatcher('/ep/pro-help/'), forward(pro_help_control)]
]);
// these paths are main site only
@@ -290,7 +289,7 @@ function checkHTTPS() {
* sure that pages that needed to be secure went over HTTPS, and pages
* that didn't go over HTTP. However, when we open-sourced the code,
- * we disabled HTTPS because we didn't want to ship the etherpad.com
+ * we disabled HTTPS because we didn't want to ship the pad.spline.inf.fu-berlin.de
* private crypto keys. --aiba */
return;